@@ -44,7 +44,7 @@ def iops(tradedata, valuechain=None, countrycode=710, tradedigit=6, statanorm=Fa
         # All data dataframe Mcp column.
         cdata['Mcp'] = 0
         cdata.loc[cdata['rca'] >= 1, 'Mcp'] = 1
-        print("RCA assignment complete")
+        print("Mcp assignment complete")
 
         print('No value chain input, calculating default at trade digit levels')
         # Aggregate raw trade data to the user specified trade digit level.
@@ -146,7 +146,7 @@ def iops(tradedata, valuechain=None, countrycode=710, tradedigit=6, statanorm=Fa
         # All data Mcp
         cdata['Mcp'] = 0
         cdata.loc[cdata['rca'] >= 1, 'Mcp'] = 1
-        print("RCA assignment complete")
+        print("Mcp assignment complete")
 
         # Value chain tier results for value chain input
         print('Starting GVC tier result calculation')
@@ -480,12 +480,12 @@ def ecomplexity(data, cols_input, statanorm=False):
         # https://github.com/cid-harvard/py-ecomplexity/blob/fed5d9b377b133a8431a05c347c4408086d789b2/ecomplexity/ecomplexity.py#L209
         if statanorm == True:
             # Normalize pci as per STATA package
-            print('Normalizing pci as per STATA package')
+            print('Normalizing PCI as per STATA package')
             cdata.pci_t = (cdata.pci_t - cdata.eci_t.mean()) / cdata.eci_t.std()
         else:
             # Normalize pci as per literature
             cdata.pci_t = (cdata.pci_t - cdata.pci_t.mean()) / cdata.pci_t.std()
-            print('Normalizing pci as per literature')
+            print('Normalizing PCI as per literature')
         # Normalize eci and cog as per STATA package
         cdata.cog_t = cdata.cog_t / cdata.eci_t.std()
         cdata.eci_t = (cdata.eci_t - cdata.eci_t.mean()) / cdata.eci_t.std()
